require(tidyverse)
require(rempsyc)

load("data_public.Rdata")

# ---- Data Preparation ----

topics <- c(
  "genderroles", 
  "race", 
  "politics", 
  "trans", 
  "religion", 
  "sexualorientation", 
  "israelipalestinian", 
  "covid", 
  "freespeech", 
  "abortion"
  )
formal_sanctions <- c(
  "stdnt_file_complaint",
  "instruc_grade",
  "instruc_letter_of_rec"
)
informal_sanctions <- c(
  "stdnt_friendship",
  "stdnt_gossip",
  "stdnt_social_media",
  "stdnt_romantic",
  "stdnt_offensive",
  "instruc_dislike",
  "instruc_offensive",
  "instruc_incorrect"
)
personality_vars <- c(
  "extraversion", 
  "neuroticism", 
  "agreeableness", 
  "conscientiousness", 
  "openness"
  )
control_vars <- c(
  "typical_discuss_score", 
  "politics_overall_num", 
  "gender_recoded", 
  personality_vars
  )
control_vars_lm <- c(
  "typical_discuss_score", 
  "politics_overall_num", 
  "gender_recodedMale", 
  "gender_recodedOther", 
  "gender_recodedFemale", 
  personality_vars
)

mean_reluctance_vars <- paste0(
  c(
    "(average of controversial topics)", 
    topics, 
    "typical"
    ), 
  "_discuss_score"
  )

data <- data %>%
  mutate(across(contains("_discuss"), ~ as.numeric(.), .names = "{col}_score"))
data$controversial_discuss_score <- data %>%
  select(paste0(topics, '_discuss_score')) %>%
  rowMeans() 
data$yearinschool_num <- as.numeric(data$yearinschool)
data$`(average of controversial topics)_discuss_score` <- data$controversial_discuss_score
data$any_informal_sanction <- as.numeric(rowSums(select(data, all_of(informal_sanctions))) >= 1)
data$any_formal_sanction <- as.numeric(rowSums(select(data, all_of(formal_sanctions))) >= 1)
data$any_sanction <- as.numeric(rowSums(select(data, all_of(c(informal_sanctions, formal_sanctions)))) >= 1)
data$politics_overall_num <- as.numeric(data$politics_overall)
data$politics_overall_bin <- factor(
  ifelse(data$politics_overall_num < 4, "Left", "Right"),
  levels=c("Left", "Right")
)

# ---- Helper Functions ----

print_lm <- function(model, title = NA, exclude_controls = TRUE, control_vars = control_vars_lm) {
  stats.table <- as.data.frame(summary(model)$coefficients)
  CI <- confint(model)
  stats.table <- cbind(row.names(stats.table), stats.table, CI)
  names(stats.table) <- c("Term", "B", "SE", "t", "p", "CI_lower", "CI_upper")
  note <- "All included variables are shown in the table"
  if (exclude_controls) {
    # Identify control variables and exclude them from stats.table
    control_indices <- match(control_vars, rownames(stats.table))
    control_indices <- control_indices[!is.na(control_indices)]  # Remove NA values
    if(length(control_indices)>0){
      stats.table <- stats.table[-control_indices, , drop = FALSE]
      note <- "Controls were included, but are not shown in the table"
    } 
  }
  return(nice_table(stats.table, highlight = 0.01, stars = FALSE, title = title,
                    note=note))
}

cont_lm <- function(data, dv, cont_var, control_vars) {
  formula <- as.formula(paste(dv, "~", paste(c(cont_var, control_vars), collapse = " + ")))
  res <- lm(formula, data = data)
  return(res)
}

demo_table <- function(variable) {
  freq_table <- table(variable)
  df <- as.data.frame(freq_table)
  colnames(df) <- c("Category", "Frequency")
  df$Percentage <- sprintf("%.2f%%", df$Frequency / sum(df$Frequency) * 100)
  return(nice_table(df))
}


# ---- Demographic Tables ----

demo_table(data$gender_recoded)
demo_table(data$race_recoded)
demo_table(data$politics_overall)
demo_table(data$religion_recoded)
demo_table(data$ipeds_inst_control)

# ---- Takeaway #1 ----

# Reluctance on Controversial Topics
data$max_reluctance_score <- apply(data[paste0(topics, '_discuss_score')], 1, max, na.rm = TRUE)
data$at_least_one_reluctant <- factor(data$max_reluctance_score >=3, labels = c("Not Reluctant", "Reluctant"))

100 * data %>% filter(at_least_one_reluctant == 'Reluctant') %>% nrow / nrow(data)

# Reluctance by topic
reluctant_prop_table <- data %>%
  select(paste0(c(topics, "typical"), "_discuss_score")) %>%
  gather(variable, value, matches("_discuss_score")) %>%
  mutate(is_reluctant = value >= 3 ) %>%
  group_by(variable, is_reluctant) %>%
  summarise(count = n(), .groups="drop_last") %>%
  mutate(prop = count / sum(count)) %>%
  filter(is_reluctant) %>%
  arrange(desc(prop))
reluctant_prop_table

reluctant_prop_table %>%
  filter(variable != "typical_discuss_score") %>%
  pull(prop) %>%
  mean()

# Personality accounts for ~4% of variance in controversial topics
personality_lm <- cont_lm(data, dv = "controversial_discuss_score", cont_var = "", control_vars = personality_vars)
summary(personality_lm)$r.squared

data %>%
  select(paste0(c(topics, "typical"), "_discuss")) %>%
  gather(variable, value, matches("_discuss")) %>%
  group_by(variable, value) %>%
  summarise(count = n(), .groups="drop_last") %>%
  mutate(prop = count / sum(count)) %>%
  filter(value %in% c("Somewhat reluctant", "Very reluctant")) %>%
  ggplot(aes(x = reorder(str_remove(variable, "_discuss"), -prop), y = prop, fill = value)) +
  geom_bar(stat = "identity", position = position_stack(reverse = TRUE)) +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  labs(
    title = "Proportion of Reluctant Students by Topic",
    x = "Topic",
    y = "Proportion",
    fill = "Reluctance Level"
  ) +
  scale_y_continuous(labels = scales::percent_format())

# Reluctance by topic by year in school
data %>%
  select(all_of(c(mean_reluctance_vars, "yearinschool"))) %>%
  group_by(yearinschool) %>%
  drop_na() %>%
  summarise_all(~mean(as.numeric(.), na.rm = TRUE)) %>%
  gather(variable, value, -yearinschool) %>%
  ggplot(aes(x = reorder(str_remove(variable, "_discuss_score"), -value), y = value, fill = as.factor(yearinschool))) +
  geom_col(position = "dodge", width = 0.7, color = "white") +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  labs(
    title = "Average Reluctance by Topic and Year in School",
    x = "Topic",
    y = "Overall Reluctance",
    fill = "Year in School"
  ) +
  scale_y_continuous(breaks = c(1, 2, 3, 4),
                     labels = c("Very comfortable", "Somewhat comfortable", "Somewhat reluctant", "Very reluctant"),
                     limits = c(0, 3))

print_lm(cont_lm(data, dv = "controversial_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="genderroles_discuss_score")

print_lm(cont_lm(data, dv = "genderroles_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="genderroles_discuss_score")
print_lm(cont_lm(data, dv = "race_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="race_discuss_score")
print_lm(cont_lm(data, dv = "politics_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="politics_discuss_score")
print_lm(cont_lm(data, dv = "trans_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="trans_discuss_score")
print_lm(cont_lm(data, dv = "religion_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="religion")
print_lm(cont_lm(data, dv = "sexualorientation_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="sexualorientation")
print_lm(cont_lm(data, dv = "israelipalestinian_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="israelipalestinian")
print_lm(cont_lm(data, dv = "covid_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="covid")
print_lm(cont_lm(data, dv = "freespeech_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="freespeech")
print_lm(cont_lm(data, dv = "abortion_discuss_score", cont_var = "yearinschool_num", control_vars = control_vars), title="abortion")

# ---- Takeaway #2 ----

# Percentage reporting adverse experience
100 * (data %>% filter(adverse_exp == 'Yes') %>% nrow) / (data %>% drop_na(adverse_exp) %>% nrow)

# Percentage were direct target
100* data %>% filter(adverse_exp_target == 'Myself') %>% nrow / (data %>% filter(adverse_exp == 'Yes') %>% nrow)
# Of total
100* data %>% filter(adverse_exp_target == 'Myself') %>% nrow / data %>% drop_na(adverse_exp) %>% nrow
# Of total (including students not asked)
100 * (data %>% filter(adverse_exp_target == 'Myself') %>% nrow) / (data %>% nrow)

data$reluctant_count_incl_typical <- rowSums(data[paste0(c(topics, "typical"), '_discuss_score')] >= 3)
data$at_least_one_reluctant_incl_typical <- ifelse(data$reluctant_count_incl_typical >= 1, "Reluctant", "Not Reluctant")

data$adverse_exp_target_full <- data$adverse_exp_target
data$adverse_exp_target_full[data$at_least_one_reluctant_incl_typical == "Not Reluctant"] <- "Not Asked about Adverse Experiences (Not Reluctant)"
data$adverse_exp_target_full[data$adverse_exp == "No"] <- "No Adverse Experience"
data$adverse_exp_target_full[is.na(data$adverse_exp_target_full)] <- "Declined to Answer"

data %>%
  ggplot(aes(x = factor(1), fill = factor(adverse_exp_target_full))) +
  geom_bar(width = 1, color = "white") +
  coord_polar(theta = "y") +
  theme_void() +
  labs(
    title = "Have you personally experienced an adverse experience?",
    fill = "",
    x = NULL,
    y = NULL
  ) +
  geom_text(
    aes(label = sprintf("%1.1f%%", ..count.. / sum(..count..) * 100)),
    stat = "count",
    position = position_stack(vjust = 0.5),
    color = "white",
    size = 4
  )

# ---- Takeaway #3 ----

informal_sanction_table <- data %>% 
  select(all_of(c(informal_sanctions, "any_informal_sanction"))) %>%
  summarise_all(~100*mean(as.numeric(.), na.rm = TRUE)) %>%
  gather(variable, value) 

informal_sanction_table %>%
  filter(variable != "any_informal_sanction") %>%
  ggplot(aes(x = reorder(variable, -value), y = value)) +
  geom_col(fill = "grey") +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  labs(title = "Percent of Students who Expected an Informal Sanction",
       x = "Sanction Type",
       y = "Percent of Students") 

formal_sanction_table <- data %>% 
  select(all_of(c(formal_sanctions, "any_formal_sanction"))) %>%
  summarise_all(~100*mean(as.numeric(.), na.rm = TRUE)) %>%
  gather(variable, value) 

formal_sanction_table %>%
  filter(variable != "any_formal_sanction") %>%
  ggplot(aes(x = reorder(variable, -value), y = value)) +
  geom_col(fill = "grey") +
  theme_minimal() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  labs(title = "Percent of Students who Expected a Formal Sanction",
       x = "Sanction Type",
       y = "Percent of Students") 

all_sanction_table <- data %>% 
  select(all_of(c(informal_sanctions, formal_sanctions, "any_sanction"))) %>%
  summarise_all(~100*mean(as.numeric(.), na.rm = TRUE)) %>%
  gather(variable, value) 
all_sanction_table

demo_table(data$stdnt_harm)

# Agreeableness
print_lm(
  cont_lm(
    data, 
    dv = "controversial_discuss_score", 
    cont_var = "agreeableness", 
    control_vars = c("gender_recoded")
  ), exclude_controls=FALSE
)

# ---- Takeaway #4 ----

demo_table(data$stdnt_debate)

# ---- Takeaway #5 ----

# Percentage of students who are left leaning
politics_bin_table <- table(data$politics_overall_bin)
politics_bin_table["Left"] / sum(politics_bin_table)

data %>%
  ggplot(aes(x = politics_overall_bin, y = controversial_discuss_score, fill = politics_overall_bin)) +
  stat_summary(fun = mean, geom = "bar", position = position_dodge()) +
  scale_fill_manual(values=c("royalblue4", "red4")) +
  labs(title = "Average Reluctance to Discuss Controversial Topics",
       x = "Overall Political Orientation",
       y = "Mean Overall Reluctance") +
  theme_minimal() +
  theme(legend.position = "none") +
  scale_y_continuous(breaks = c(1, 2, 3, 4),
                     labels = c("Very comfortable", "Somewhat comfortable", "Somewhat reluctant", "Very reluctant")) +
  coord_cartesian(ylim = c(0, 3))

data %>%
  select(paste0(topics, "_discuss_score"), "politics_overall_bin") %>%
  group_by(politics_overall_bin) %>%
  summarise_all(~mean(as.numeric(.), na.rm = TRUE)) %>%
  gather(variable, value, -politics_overall_bin) %>%
  ggplot(aes(x = reorder(str_remove(variable, "_discuss_score"), -value), y = value, fill = as.factor(politics_overall_bin))) +
  geom_col(position = "dodge", width = 0.7, color = "white") +
  theme_minimal() +
  scale_fill_manual(values=c("royalblue4", "red4")) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  labs(
    title = "Average Reluctance by Topic and Overall Political Orientation",
    x = "Topic",
    y = "Overall Reluctance",
    fill = "Political Orientation"
  ) +
  scale_y_continuous(breaks = c(1, 2, 3, 4),
                     labels = c("Very comfortable", "Somewhat comfortable", "Somewhat reluctant", "Very reluctant"),
                     limits = c(0, 3)) 

mean_right <- data %>% filter(politics_overall_bin == "Right") %>% pull(controversial_discuss_score) %>% mean
mean_left <- data %>% filter(politics_overall_bin == "Left") %>% pull(controversial_discuss_score) %>% mean

100*(1-(mean_left / mean_right))

# Regressions

control_non_political_vars <- c("typical_discuss_score", "gender_recoded", "extraversion",
                                "neuroticism", "agreeableness", "conscientiousness", "openness")

res_politics_overall <- cont_lm(data, dv = "controversial_discuss_score", 
                                cont_var = "politics_overall_num",
                                control_vars = control_non_political_vars)
print_lm(res_politics_overall, exclude_controls = FALSE)

print_lm(cont_lm(data, dv = "genderroles_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="genderroles_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "race_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="race_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "politics_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="politics_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "trans_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="trans_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "religion_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="religion_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "sexualorientation_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="sexualorientation_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "israelipalestinian_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="israelipalestinian_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "covid_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="covid_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "freespeech_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="freespeech_discuss_score", exclude_controls=FALSE)
print_lm(cont_lm(data, dv = "abortion_discuss_score", cont_var = "politics_overall_num", control_vars = control_non_political_vars), title="abortion_discuss_score", exclude_controls=FALSE)

# ---- Takeaway #6 ----

data %>%
  ggplot(aes(x = politics_overall, y = controversial_discuss_score, fill = politics_overall)) +
  stat_summary(fun = mean, geom = "bar", position = position_dodge()) +
  scale_fill_brewer(palette = "RdBu", direction = -1) +
  labs(title = "Average Reluctance to Discuss Controversial Topics",
       x = "Overall Political Orientation",
       y = "Mean Overall Reluctance") +
  theme_minimal() +
  theme(legend.position = "none") +
  scale_y_continuous(breaks = c(1, 2, 3, 4),
                     labels = c("Very comfortable", "Somewhat comfortable", "Somewhat reluctant", "Very reluctant")) +
  coord_cartesian(ylim = c(0, 3))

data %>%
  select(mean_reluctance_vars, "politics_overall") %>%
  group_by(politics_overall) %>%
  summarise_all(~mean(as.numeric(.), na.rm = TRUE)) %>%
  gather(variable, value, -politics_overall) %>%
  ggplot(aes(x = reorder(str_remove(variable, "_discuss_score"), -value), y = value, fill = as.factor(politics_overall))) +
  geom_col(position = "dodge", width = 0.7, color = "white") +
  theme_minimal() +
  scale_fill_brewer(palette = "RdBu", direction = -1) +  
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  labs(
    title = "Average Reluctance by Topic and Overall Political Orientation",
    x = "Topic",
    y = "Overall Reluctance",
    fill = "Political Orientation"
  ) +
  scale_y_continuous(breaks = c(1, 2, 3, 4),
                     labels = c("Very comfortable", "Somewhat comfortable", "Somewhat reluctant", "Very reluctant"),
                     limits = c(0, 3)) 

# Summary statistics
comfort_score_by_politics <- data %>%
  group_by(politics_overall) %>%
  summarise(overall_score = mean(controversial_discuss_score))

very_left_score <- comfort_score_by_politics %>% filter(politics_overall == "Very left") %>% pull(overall_score)
lean_left_score <- comfort_score_by_politics %>% filter(politics_overall == "Lean left") %>% pull(overall_score)
very_right_score  <- comfort_score_by_politics %>% filter(politics_overall == "Very right") %>% pull(overall_score)
lean_right_score  <- comfort_score_by_politics %>% filter(politics_overall == "Lean right") %>% pull(overall_score)

100 * ((lean_left_score / very_left_score) - 1)
100 * ((lean_right_score / very_right_score) - 1)

politics_prop_table <- prop.table(table(data$politics_overall))
as.numeric(politics_prop_table["Very left"] + politics_prop_table["Very right"])

# Regressions
res_politics_overall_quad <- lm(controversial_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data)
print_lm(res_politics_overall_quad, exclude_controls = FALSE)

quad_anova <- anova(res_politics_overall_quad, res_politics_overall)
quad_anova

print_lm(lm(genderroles_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="genderroles_discuss_score")
print_lm(lm(race_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="race_discuss_score")
print_lm(lm(politics_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="politics_discuss_score")
print_lm(lm(trans_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="trans_discuss_score")
print_lm(lm(religion_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="religion_discuss_score")
print_lm(lm(sexualorientation_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="sexualorientation_discuss_score")
print_lm(lm(israelipalestinian_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="israelipalestinian_discuss_score")
print_lm(lm(covid_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="covid_discuss_score")
print_lm(lm(freespeech_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="freespeech_discuss_score")
print_lm(lm(abortion_discuss_score ~ poly(politics_overall_num, 2) + typical_discuss_score + gender_recoded + extraversion + neuroticism + agreeableness + conscientiousness + openness, data=data), title="abortion_discuss_score")
